searchData={"items":[{"type":"module","title":"Phoenix.Socket.V2.BERTSerializer","doc":"A serializer for `Phoenix.Socket` that encodes messages using BERT (Binary ERlang Term)\n\nFallback to Phoenix.Socket.V2.JSONSerializer for decoding messages that are not BERT encoded","ref":"Phoenix.Socket.V2.BERTSerializer.html"},{"type":"module","title":"Usage - Phoenix.Socket.V2.BERTSerializer","doc":"Set the `:serializer` option in your `Phoenix.Socket` configuration:\n\n  **endpoint.ex**\n\n    socket \"/live\", Phoenix.LiveView.Socket,\n      longpoll: [connect_info: [session: @session_options]],\n      websocket: [\n        connect_info: [session: @session_options],\n        serializer: [{Phoenix.Socket.V2.BERTSerializer, \"~> 2.0.0\"}]\n      ]\n\n    socket \"/socket\", Phoenix.Socket,\n      websocket: [\n        serializer: [{Phoenix.Socket.V2.BERTSerializer, \"~> 2.0.0\"}]\n      ]\n\nImport the `phoenix_socket_bert` in your app.js and add `decode` option to the `LiveSocket` configuration:\n\n  **app.js**\n\n    import { decode } from 'phoenix_socket_bert'\n    import { LiveSocket } from 'phoenix_live_view'\n    import { Socket } from 'phoenix'\n\n    let csrfToken = document.querySelector('meta[name=\"csrf-token\"]').getAttribute('content')\n    let liveSocket = new LiveSocket('/live', Socket, {\n      decode: decode,\n      longPollFallbackMs: 2500,\n      params: { _csrf_token: csrfToken }\n    })\n\n    liveSocket.connect()\n\n    let socket = new Socket(\"/socket\", { decode: decode, params: { token: csrfToken } })\n    socket.connect()","ref":"Phoenix.Socket.V2.BERTSerializer.html#module-usage"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.0.7 (2025-05-25) - Changelog","doc":"* Enhancements\n\n  * Update mix.lock\n  * Add `:phoenix` as a dependency","ref":"changelog.html#1-0-7-2025-05-25"},{"type":"extras","title":"1.0.6 (2025-05-11) - Changelog","doc":"* Enhancements\n\n  * Update mix.lock\n  * Sync package.json version with `MixProject` version","ref":"changelog.html#1-0-6-2025-05-11"},{"type":"extras","title":"1.0.5 (2025-03-28) - Changelog","doc":"* Enhancements\n\n  * Update mix.lock","ref":"changelog.html#1-0-5-2025-03-28"},{"type":"extras","title":"1.0.4 (2024-02-06) - Changelog","doc":"* Bug fixes\n\n  * Fix hex.pm changelog link","ref":"changelog.html#1-0-4-2024-02-06"},{"type":"extras","title":"1.0.3 (2024-01-18) - Changelog","doc":"* Enhancements\n\n  * Improve decoding performance","ref":"changelog.html#1-0-3-2024-01-18"},{"type":"extras","title":"1.0.2 (2024-01-18) - Changelog","doc":"* Enhancements\n\n  * Fallback to Phoenix default decoder","ref":"changelog.html#1-0-2-2024-01-18"},{"type":"extras","title":"1.0.1 (2024-01-13) - Changelog","doc":"* Enhancements\n\n  * Update description\n  * Add refs to README","ref":"changelog.html#1-0-1-2024-01-13"},{"type":"extras","title":"1.0.0 (2024-01-09) - Changelog","doc":"* Added\n\n  * Publish hex package","ref":"changelog.html#1-0-0-2024-01-09"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025-present Youimmi\n          (c) 2025-present Yuri S.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"PhoenixSocketBert","doc":"# PhoenixSocketBert\n\nA serializer for `Phoenix.Socket` that encodes messages using BERT (Binary ERlang Term)\n\n[![Hex.pm](https://img.shields.io/hexpm/v/phoenix_socket_bert.svg)](https://hex.pm/packages/phoenix_socket_bert) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/phoenix_socket_bert)","ref":"readme.html"},{"type":"extras","title":"Installation - PhoenixSocketBert","doc":"Add `phoenix_socket_bert` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_socket_bert, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PhoenixSocketBert","doc":"Set the `:serializer` option in your `Phoenix.Socket` configuration:\n\n**endpoint.ex**\n\n```elixir\nsocket \"/live\", Phoenix.LiveView.Socket,\n  longpoll: [connect_info: [session: @session_options]],\n  websocket: [\n    connect_info: [session: @session_options],\n    serializer: [{Phoenix.Socket.V2.BERTSerializer, \"~> 2.0.0\"}]\n  ]\n\nsocket \"/socket\", Phoenix.Socket,\n  websocket: [\n    serializer: [{Phoenix.Socket.V2.BERTSerializer, \"~> 2.0.0\"}]\n  ]\n```\n\nImport the `phoenix_socket_bert` in your app.js and add `decode` option to the `LiveSocket` configuration:\n\n**app.js**\n\n```javascript\nimport { decode } from 'phoenix_socket_bert'\nimport { LiveSocket } from 'phoenix_live_view'\nimport { Socket } from 'phoenix'\n\nlet csrfToken = document.querySelector('meta[name=\"csrf-token\"]').getAttribute('content')\nlet liveSocket = new LiveSocket('/live', Socket, {\n  decode: decode,\n  longPollFallbackMs: 2500,\n  params: { _csrf_token: csrfToken }\n})\n\nliveSocket.connect()\n\nlet socket = new Socket(\"/socket\", { decode: decode, params: { token: csrfToken } })\nsocket.connect()\n```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - PhoenixSocketBert","doc":"To contribute you need to compile `PhoenixSocketBert` from source:\n\n```\n$ git clone https://github.com/Youimmi/phoenix_socket_bert.git\n$ cd phoenix_socket_bert\n```","ref":"readme.html#contributing"},{"type":"extras","title":"Refs - PhoenixSocketBert","doc":"This package is based on the excellent example https://github.com/zookzook/binary_ws by [zookzook (Michael Maier)](https://github.com/zookzook)\n\nRelated to the discussion: https://github.com/phoenixframework/phoenix_live_view/issues/616","ref":"readme.html#refs"},{"type":"extras","title":"Copyright and License - PhoenixSocketBert","doc":"**PhoenixSocketBert** is released under [the MIT License](./LICENSE)","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}